@@ -75,7 +75,7 @@ namespace stan {
         model_r.name("model declaration (or perhaps an earlier block)");
         model_r
           %= lit("model")
-          > statement_g(true, local_origin, false);
+          > statement_g(true, local_origin, false, false);
 
         end_var_decls_r.name(
             "one of the following:\n"
@@ -115,10 +115,10 @@ namespace stan {
                >> lit("data"))
               > lit('{'))
           > var_decls_g(true, transformed_data_origin)  // -constraints
-          > ((statement_g(false, transformed_data_origin, false)
-              > *statement_g(false, transformed_data_origin, false)
+          > ((statement_g(false, transformed_data_origin, false, false)
+              > *statement_g(false, transformed_data_origin, false, false)
               > end_var_definitions_r)
-             | (*statement_g(false, transformed_data_origin, false)
+             | (*statement_g(false, transformed_data_origin, false, false)
                 > end_var_decls_statements_r));
 
         param_var_decls_r.name("parameter variable declarations");
@@ -134,7 +134,7 @@ namespace stan {
               > lit("parameters")
               > lit('{'))
           > var_decls_g(true, transformed_parameter_origin)
-          > *statement_g(false, transformed_parameter_origin, false)
+          > *statement_g(false, transformed_parameter_origin, false, false)
           > end_var_decls_statements_r;
 
         generated_var_decls_r.name("generated variable declarations");
@@ -143,7 +143,7 @@ namespace stan {
               > lit("quantities")
               > lit('{'))
           > var_decls_g(true, derived_origin)
-          > *statement_g(false, derived_origin, false)
+          > *statement_g(false, derived_origin, false, false)
           > end_var_decls_statements_r;
 
         on_error<rethrow>(program_r,
