@@ -2,8 +2,8 @@
 #define STAN_MCMC_HMC_HAMILTONIANS_PS_POINT_HPP
 
 #include <stan/interface_callbacks/writer/base_writer.hpp>
-#include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <boost/lexical_cast.hpp>
+#include <Eigen/Dense>
 #include <string>
 #include <vector>
 
