@@ -1,20 +1,21 @@
 #ifndef STAN_MCMC_HMC_STATIC_BASE_STATIC_HMC_HPP
 #define STAN_MCMC_HMC_STATIC_BASE_STATIC_HMC_HPP
 
-#include <boost/math/special_functions/fpclassify.hpp>
+#include <stan/interface_callbacks/writer/base_writer.hpp>
 #include <stan/mcmc/hmc/base_hmc.hpp>
 #include <stan/mcmc/hmc/hamiltonians/ps_point.hpp>
+#include <boost/math/special_functions/fpclassify.hpp>
 #include <cmath>
 #include <limits>
 #include <string>
 #include <vector>
 
 namespace stan {
-
   namespace mcmc {
-
-    // Hamiltonian Monte Carlo
-    // with static integration time
+    /**
+     * Hamiltonian Monte Carlo implementation using the endpoint
+     * of trajectories with a static integration time
+     */
     template <class Model,
               template<class, class> class Hamiltonian,
               template<class> class Integrator,
@@ -22,22 +23,24 @@ namespace stan {
     class base_static_hmc
       : public base_hmc<Model, Hamiltonian, Integrator, BaseRNG> {
     public:
-      base_static_hmc(Model &model, BaseRNG& rng,
-                      std::ostream* o, std::ostream* e)
-        : base_hmc<Model, Hamiltonian, Integrator, BaseRNG>(model, rng, o, e),
-        T_(1) {
+      base_static_hmc(const Model& model, BaseRNG& rng)
+        : base_hmc<Model, Hamiltonian, Integrator, BaseRNG>(model, rng),
+        T_(1), energy_(0) {
         update_L_();
       }
 
       ~base_static_hmc() {}
 
-      sample transition(sample& init_sample) {
+      sample
+      transition(sample& init_sample,
+                 interface_callbacks::writer::base_writer& info_writer,
+                 interface_callbacks::writer::base_writer& error_writer) {
         this->sample_stepsize();
 
         this->seed(init_sample.cont_params());
 
         this->hamiltonian_.sample_p(this->z_, this->rand_int_);
-        this->hamiltonian_.init(this->z_);
+        this->hamiltonian_.init(this->z_, info_writer, error_writer);
 
         ps_point z_init(this->z_);
 
@@ -45,7 +48,8 @@ namespace stan {
 
         for (int i = 0; i < L_; ++i)
           this->integrator_.evolve(this->z_, this->hamiltonian_,
-                                   this->epsilon_);
+                                   this->epsilon_,
+                                   info_writer, error_writer);
 
         double h = this->hamiltonian_.H(this->z_);
         if (boost::math::isnan(h)) h = std::numeric_limits<double>::infinity();
@@ -57,25 +61,20 @@ namespace stan {
 
         acceptProb = acceptProb > 1 ? 1 : acceptProb;
 
+        this->energy_ = this->hamiltonian_.H(this->z_);
         return sample(this->z_.q, - this->hamiltonian_.V(this->z_), acceptProb);
       }
 
-      void write_sampler_param_names(std::ostream& o) {
-        o << "stepsize__,int_time__,";
-      }
-
-      void write_sampler_params(std::ostream& o) {
-        o << this->epsilon_ << "," << this->T_ << ",";
-      }
-
       void get_sampler_param_names(std::vector<std::string>& names) {
         names.push_back("stepsize__");
         names.push_back("int_time__");
+        names.push_back("energy__");
       }
 
       void get_sampler_params(std::vector<double>& values) {
         values.push_back(this->epsilon_);
         values.push_back(this->T_);
+        values.push_back(this->energy_);
       }
 
       void set_nominal_stepsize_and_T(const double e, const double t) {
@@ -118,6 +117,7 @@ namespace stan {
     protected:
       double T_;
       int L_;
+      double energy_;
 
       void update_L_() {
         L_ = static_cast<int>(T_ / this->nom_epsilon_);
