@@ -7,15 +7,12 @@
 #include <stan/math/prim/scal/fun/trigamma.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <typename T>
     inline
     fvar<T>
     digamma(const fvar<T>& x) {
-      using stan::math::digamma;
-      using stan::math::trigamma;
       return fvar<T>(digamma(x.val_), x.d_ * trigamma(x.val_));
     }
   }
