@@ -15,9 +15,8 @@ namespace stan {
       using ::erf;
       using std::sqrt;
       using std::exp;
-      using stan::math::square;
-      return fvar<T>(erf(x.val_), x.d_ * exp(-square(x.val_))
-                                  * stan::math::TWO_OVER_SQRT_PI);
+      return fvar<T>(erf(x.val_),
+                     x.d_ * exp(-square(x.val_)) * TWO_OVER_SQRT_PI);
     }
 
   }
