@@ -7,15 +7,12 @@
 #include <stan/math/prim/scal/fun/constants.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <typename T>
     inline
     fvar<T>
     log1m(const fvar<T>& x) {
-      using stan::math::log1m;
-      using stan::math::NOT_A_NUMBER;
       if (x.val_ > 1.0)
         return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
       else
