@@ -18,7 +18,7 @@ namespace stan {
     template <typename T, int R, int C>
     inline T log_determinant_spd(const Eigen::Matrix<T, R, C>& m) {
       using std::log;
-      stan::math::check_square("log_determinant_spd", "m", m);
+      check_square("log_determinant_spd", "m", m);
       //      Eigen::TriangularView< Eigen::Matrix<T, R, C>, Eigen::Lower >
       //        L(m.llt().matrixL());
       //      T ret(0.0);
