@@ -18,41 +18,30 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_n, typename T_prob>
     typename return_type<T_prob>::type
     bernoulli_cdf_log(const T_n& n, const T_prob& theta) {
-      static const char* function("stan::math::bernoulli_cdf_log");
+      static const char* function("bernoulli_cdf_log");
       typedef typename stan::partials_return_type<T_n, T_prob>::type
         T_partials_return;
 
-      using stan::math::check_finite;
-      using stan::math::check_bounded;
-      using stan::math::check_consistent_sizes;
-      using stan::math::include_summand;
-
-      // Ensure non-zero argument lenghts
       if (!(stan::length(n) && stan::length(theta)))
         return 0.0;
 
       T_partials_return P(0.0);
 
-      // Validate arguments
       check_finite(function, "Probability parameter", theta);
       check_bounded(function, "Probability parameter", theta, 0.0, 1.0);
       check_consistent_sizes(function,
                              "Random variable", n,
                              "Probability parameter", theta);
 
-      // set up template expressions wrapping scalars into vector views
       VectorView<const T_n> n_vec(n);
       VectorView<const T_prob> theta_vec(theta);
       size_t size = max_size(n, theta);
 
-      // Compute vectorized cdf_log and gradient
-      using stan::math::value_of;
       using std::log;
       OperandsAndPartials<T_prob> operands_and_partials(theta);
 
@@ -60,7 +49,7 @@ namespace stan {
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(n); i++) {
         if (value_of(n_vec[i]) < 0)
-          return operands_and_partials.value(stan::math::negative_infinity());
+          return operands_and_partials.value(negative_infinity());
       }
 
       for (size_t i = 0; i < size; i++) {
