@@ -21,7 +21,6 @@
 #include <stan/math/prim/scal/fun/inc_beta.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -31,11 +30,7 @@ namespace stan {
              RNG& rng) {
       using boost::variate_generator;
       using boost::random::gamma_distribution;
-      // Error checks
-      static const char* function("stan::math::beta_rng");
-
-      using stan::math::check_positive_finite;
-
+      static const char* function("beta_rng");
       check_positive_finite(function, "First shape parameter", alpha);
       check_positive_finite(function, "Second shape parameter", beta);
 
