@@ -16,7 +16,6 @@
 #include <stan/math/prim/scal/meta/include_summand.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -26,9 +25,7 @@ namespace stan {
       using boost::variate_generator;
       using boost::random::chi_squared_distribution;
 
-      static const char* function("stan::math::chi_square_rng");
-
-      using stan::math::check_positive_finite;
+      static const char* function("chi_square_rng");
 
       check_positive_finite(function, "Degrees of freedom parameter", nu);
 
@@ -36,6 +33,7 @@ namespace stan {
         chi_square_rng(rng, chi_squared_distribution<>(nu));
       return chi_square_rng();
     }
+
   }
 }
 #endif
