@@ -13,7 +13,7 @@
 #include <stan/math/prim/scal/fun/constants.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <stan/math/prim/scal/fun/lgamma.hpp>
-#include <stan/math/prim/scal/fun/gamma_q.hpp>
+#include <stan/math/prim/scal/fun/gamma_p.hpp>
 #include <stan/math/prim/scal/fun/digamma.hpp>
 #include <stan/math/prim/scal/meta/length.hpp>
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
@@ -27,7 +27,6 @@
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_shape, typename T_scale>
@@ -37,20 +36,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_shape, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if (!(stan::length(y) && stan::length(alpha) && stan::length(beta)))
         return 0.0;
 
-      // Error checks
-      static const char* function("stan::math::inv_gamma_ccdf_log");
+      static const char* function("inv_gamma_ccdf_log");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_greater_or_equal;
-      using stan::math::check_less_or_equal;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using boost::math::tools::promote_args;
       using std::exp;
 
@@ -65,7 +55,6 @@ namespace stan {
                              "Shape parameter", alpha,
                              "Scale Parameter", beta);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_shape> alpha_vec(alpha);
       VectorView<const T_scale> beta_vec(beta);
@@ -76,21 +65,16 @@ namespace stan {
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
-
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
           return operands_and_partials.value(0.0);
       }
 
-      // Compute ccdf_log and its gradients
-      using stan::math::gamma_q;
-      using stan::math::digamma;
       using boost::math::tgamma;
       using std::exp;
       using std::pow;
       using std::log;
 
-      // Cache a few expensive function calls if nu is a parameter
       VectorBuilder<!is_constant_struct<T_shape>::value,
                     T_partials_return, T_shape> gamma_vec(stan::length(alpha));
       VectorBuilder<!is_constant_struct<T_shape>::value,
@@ -105,22 +89,19 @@ namespace stan {
         }
       }
 
-      // Compute vectorized ccdf_log and gradient
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
         if (value_of(y_vec[n]) == std::numeric_limits<double>::infinity())
-          return operands_and_partials.value(stan::math::negative_infinity());
+          return operands_and_partials.value(negative_infinity());
 
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return y_inv_dbl = 1.0 / y_dbl;
         const T_partials_return alpha_dbl = value_of(alpha_vec[n]);
         const T_partials_return beta_dbl = value_of(beta_vec[n]);
 
-        // Compute
-        const T_partials_return Pn = 1.0 - gamma_q(alpha_dbl, beta_dbl
-                                                   * y_inv_dbl);
+        const T_partials_return Pn = gamma_p(alpha_dbl, beta_dbl
+                                             * y_inv_dbl);
 
         P += log(Pn);
 
@@ -131,19 +112,18 @@ namespace stan {
             / tgamma(alpha_dbl) / Pn;
         if (!is_constant_struct<T_shape>::value)
           operands_and_partials.d_x2[n]
-            -= stan::math::grad_reg_inc_gamma(alpha_dbl, beta_dbl
-                                              * y_inv_dbl, gamma_vec[n],
-                                              digamma_vec[n]) / Pn;
+            -= grad_reg_inc_gamma(alpha_dbl, beta_dbl
+                                  * y_inv_dbl, gamma_vec[n],
+                                  digamma_vec[n]) / Pn;
         if (!is_constant_struct<T_scale>::value)
           operands_and_partials.d_x3[n] += y_inv_dbl
             * exp(-beta_dbl * y_inv_dbl)
             * pow(beta_dbl * y_inv_dbl, alpha_dbl-1)
             / tgamma(alpha_dbl) / Pn;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
-
 #endif
