@@ -22,7 +22,6 @@
 #include <boost/random/variate_generator.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
@@ -33,9 +32,7 @@ namespace stan {
       using boost::variate_generator;
       using boost::random::gamma_distribution;
 
-      static const char* function("stan::math::inv_gamma_rng");
-
-      using stan::math::check_positive_finite;
+      static const char* function("inv_gamma_rng");
 
       check_positive_finite(function, "Shape parameter", alpha);
       check_positive_finite(function, "Scale parameter", beta);
@@ -44,7 +41,7 @@ namespace stan {
         gamma_rng(rng, gamma_distribution<>(alpha, 1 / beta));
       return 1 / gamma_rng();
     }
+
   }
 }
-
 #endif
