@@ -25,33 +25,24 @@ namespace stan {
   namespace math {
 
     // Logistic(y|mu, sigma)    [sigma > 0]
-    // FIXME: document
     template <bool propto,
               typename T_y, typename T_loc, typename T_scale>
     typename return_type<T_y, T_loc, T_scale>::type
     logistic_log(const T_y& y, const T_loc& mu, const T_scale& sigma) {
-      static const char* function("stan::math::logistic_log");
+      static const char* function("logistic_log");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
-      using stan::math::check_consistent_sizes;
-      using stan::math::value_of;
-      using stan::math::include_summand;
       using std::log;
       using std::exp;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)))
         return 0.0;
 
-      // set up return value accumulator
       T_partials_return logp(0.0);
 
-      // validate args (here done over var, which should be OK)
       check_finite(function, "Random variable", y);
       check_finite(function, "Location parameter", mu);
       check_positive_finite(function, "Scale parameter", sigma);
@@ -60,12 +51,9 @@ namespace stan {
                              "Location parameter", mu,
                              "Scale parameter", sigma);
 
-      // check if no variables are involved and prop-to
       if (!include_summand<propto, T_y, T_loc, T_scale>::value)
         return 0.0;
 
-
-      // set up template expressions wrapping scalars into vector views
       OperandsAndPartials<T_y, T_loc, T_scale>
         operands_and_partials(y, mu, sigma);
 
@@ -98,7 +86,6 @@ namespace stan {
                                    / value_of(sigma_vec[n]));
       }
 
-      using stan::math::log1p;
       for (size_t n = 0; n < N; n++) {
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return mu_dbl = value_of(mu_vec[n]);
@@ -142,6 +129,7 @@ namespace stan {
     logistic_log(const T_y& y, const T_loc& mu, const T_scale& sigma) {
       return logistic_log<false>(y, mu, sigma);
     }
+
   }
 }
 #endif
