@@ -23,23 +23,17 @@ namespace stan {
     template <typename T_y, typename T_loc, typename T_scale>
     typename return_type<T_y, T_loc, T_scale>::type
     lognormal_cdf(const T_y& y, const T_loc& mu, const T_scale& sigma) {
-      static const char* function("stan::math::lognormal_cdf");
+      static const char* function("lognormal_cdf");
 
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale>::type
         T_partials_return;
 
       T_partials_return cdf = 1.0;
 
-      using stan::math::check_not_nan;
-      using stan::math::check_finite;
-      using stan::math::check_nonnegative;
-      using stan::math::check_positive_finite;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
       using std::exp;
       using std::log;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)))
@@ -58,7 +52,7 @@ namespace stan {
       VectorView<const T_scale> sigma_vec(sigma);
       size_t N = max_size(y, mu, sigma);
 
-      const double sqrt_pi = std::sqrt(stan::math::pi());
+      const double sqrt_pi = std::sqrt(pi());
 
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0.0)
@@ -74,11 +68,9 @@ namespace stan {
         const T_partials_return rep_deriv = SQRT_2 * 0.5 / sqrt_pi
           * exp(-scaled_diff * scaled_diff) / sigma_dbl;
 
-        // cdf
         const T_partials_return cdf_ = 0.5 * erfc(-scaled_diff);
         cdf *= cdf_;
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] += rep_deriv / cdf_ / y_dbl;
         if (!is_constant_struct<T_loc>::value)
@@ -100,9 +92,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(sigma); ++n)
           operands_and_partials.d_x3[n] *= cdf;
       }
-
       return operands_and_partials.value(cdf);
     }
+
   }
 }
 #endif
