@@ -18,17 +18,12 @@ namespace stan {
     neg_binomial_2_ccdf_log(const T_n& n,
                             const T_location& mu,
                             const T_precision& phi) {
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-
-      // check if any vectors are zero length
       if (!(stan::length(n)
             && stan::length(mu)
             && stan::length(phi)))
         return 0.0;
 
-      static const char* function("stan::math::neg_binomial_2_cdf");
+      static const char* function("neg_binomial_2_cdf");
       check_positive_finite(function, "Location parameter", mu);
       check_positive_finite(function, "Precision parameter", phi);
       check_not_nan(function, "Random variable", n);
@@ -49,6 +44,7 @@ namespace stan {
 
       return neg_binomial_ccdf_log(n, phi, beta_vec.data());
     }
+
   }
 }
 #endif
