@@ -17,7 +17,6 @@
 #include <cmath>
 #include <limits>
 
-
 namespace stan {
   namespace math {
 
@@ -27,20 +26,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_scale, T_shape>::type
         T_partials_return;
 
-      // Check sizes
-      // Size checks
       if ( !( stan::length(y) && stan::length(y_min) && stan::length(alpha) ) )
         return 1.0;
 
-      // Check errors
-      static const char* function("stan::math::pareto_cdf");
+      static const char* function("pareto_cdf");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_greater_or_equal;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using std::log;
       using std::exp;
 
@@ -55,7 +45,6 @@ namespace stan {
                              "Scale parameter", y_min,
                              "Shape parameter", alpha);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_scale> y_min_vec(y_min);
       VectorView<const T_shape> alpha_vec(alpha);
@@ -66,13 +55,11 @@ namespace stan {
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
-
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) < value_of(y_min_vec[i]))
           return operands_and_partials.value(0.0);
       }
 
-      // Compute vectorized CDF and its gradients
 
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
@@ -81,13 +68,11 @@ namespace stan {
           continue;
         }
 
-        // Pull out values
         const T_partials_return log_dbl = log(value_of(y_min_vec[n])
                                               / value_of(y_vec[n]));
         const T_partials_return y_min_inv_dbl = 1.0 / value_of(y_min_vec[n]);
         const T_partials_return alpha_dbl = value_of(alpha_vec[n]);
 
-        // Compute
         const T_partials_return Pn = 1.0 - exp(alpha_dbl * log_dbl);
 
         P *= Pn;
@@ -116,9 +101,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(alpha); ++n)
           operands_and_partials.d_x3[n] *= P;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
