@@ -12,50 +12,37 @@
 #include <stan/math/prim/scal/fun/multiply_log.hpp>
 #include <stan/math/prim/scal/fun/gamma_q.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
 #include <boost/random/poisson_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
 #include <cmath>
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     // Poisson CDF
     template <typename T_n, typename T_rate>
     typename return_type<T_rate>::type
     poisson_cdf(const T_n& n, const T_rate& lambda) {
-      static const char* function("stan::math::poisson_cdf");
+      static const char* function("poisson_cdf");
       typedef typename stan::partials_return_type<T_n, T_rate>::type
         T_partials_return;
 
-      using stan::math::check_not_nan;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
-
-      // Ensure non-zero argument slengths
       if (!(stan::length(n) && stan::length(lambda)))
         return 1.0;
 
       T_partials_return P(1.0);
 
-      // Validate arguments
       check_not_nan(function, "Rate parameter", lambda);
       check_nonnegative(function, "Rate parameter", lambda);
       check_consistent_sizes(function,
                              "Random variable", n,
                              "Rate parameter", lambda);
 
-      // Wrap arguments into vector views
       VectorView<const T_n> n_vec(n);
       VectorView<const T_rate> lambda_vec(lambda);
       size_t size = max_size(n, lambda);
 
-      // Compute vectorized CDF and gradient
-      using stan::math::value_of;
-      using stan::math::gamma_q;
       using boost::math::tgamma;
       using std::exp;
       using std::pow;
@@ -91,9 +78,9 @@ namespace stan {
         for (size_t i = 0; i < stan::length(lambda); ++i)
           operands_and_partials.d_x1[i] *= P;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
