@@ -15,14 +15,12 @@
 #include <stan/math/prim/scal/meta/include_summand.hpp>
 #include <stan/math/prim/scal/meta/VectorView.hpp>
 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
 #include <boost/random/poisson_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
 #include <cmath>
 #include <limits>
 
 namespace stan {
-
   namespace math {
 
     // PoissonLog(n|alpha)  [n >= 0]   = Poisson(n|exp(alpha))
@@ -33,37 +31,26 @@ namespace stan {
       typedef typename stan::partials_return_type<T_n, T_log_rate>::type
         T_partials_return;
 
-      static const char* function("stan::math::poisson_log_log");
+      static const char* function("poisson_log_log");
 
       using boost::math::lgamma;
-      using stan::math::check_not_nan;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
-      using stan::math::check_consistent_sizes;
-      using stan::math::include_summand;
-      using std::exp;
       using std::exp;
 
-      // check if any vectors are zero length
       if (!(stan::length(n)
             && stan::length(alpha)))
         return 0.0;
 
-      // set up return value accumulator
       T_partials_return logp(0.0);
 
-      // validate args
       check_nonnegative(function, "Random variable", n);
       check_not_nan(function, "Log rate parameter", alpha);
       check_consistent_sizes(function,
                              "Random variable", n,
                              "Log rate parameter", alpha);
 
-      // check if no variables are involved and prop-to
       if (!include_summand<propto, T_log_rate>::value)
         return 0.0;
 
-      // set up expression templates wrapping scalars/vecs into vector views
       VectorView<const T_n> n_vec(n);
       VectorView<const T_log_rate> alpha_vec(alpha);
       size_t size = max_size(n, alpha);
@@ -77,7 +64,6 @@ namespace stan {
             && n_vec[i] != 0)
           return LOG_ZERO;
 
-      // return accumulator with gradients
       OperandsAndPartials<T_log_rate> operands_and_partials(alpha);
 
       // FIXME: cache value_of for alpha_vec?  faster if only one?
@@ -88,7 +74,6 @@ namespace stan {
         if (include_summand<propto, T_log_rate>::value)
           exp_alpha[i] = exp(value_of(alpha_vec[i]));
 
-      using stan::math::multiply_log;
       for (size_t i = 0; i < size; i++) {
         if (!(alpha_vec[i] == -std::numeric_limits<double>::infinity()
               && n_vec[i] == 0)) {
@@ -98,7 +83,6 @@ namespace stan {
             logp += n_vec[i] * value_of(alpha_vec[i]) - exp_alpha[i];
         }
 
-        // gradients
         if (!is_constant_struct<T_log_rate>::value)
           operands_and_partials.d_x1[i] += n_vec[i] - exp_alpha[i];
       }
@@ -112,6 +96,7 @@ namespace stan {
     poisson_log_log(const T_n& n, const T_log_rate& alpha) {
       return poisson_log_log<false>(n, alpha);
     }
+
   }
 }
 #endif
