@@ -24,9 +24,7 @@
 #include <limits>
 #include <cmath>
 
-
 namespace stan {
-
   namespace math {
 
     /**
@@ -42,7 +40,6 @@ namespace stan {
      * @tparam T_y Type of scalar.
      * @tparam T_dof Type of degrees of freedom.
      */
-
     template <typename T_y, typename T_dof, typename T_scale>
     typename return_type<T_y, T_dof, T_scale>::type
     scaled_inv_chi_square_cdf(const T_y& y, const T_dof& nu,
@@ -50,17 +47,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_dof, T_scale>::type
         T_partials_return;
 
-      // Size checks
       if (!(stan::length(y) && stan::length(nu) && stan::length(s)))
         return 1.0;
 
-      static const char* function("stan::math::scaled_inv_chi_square_cdf");
+      static const char* function("scaled_inv_chi_square_cdf");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using std::exp;
 
       T_partials_return P(1.0);
@@ -74,7 +65,6 @@ namespace stan {
                              "Degrees of freedom parameter", nu,
                              "Scale parameter", s);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_dof> nu_vec(nu);
       VectorView<const T_scale> s_vec(s);
@@ -85,20 +75,15 @@ namespace stan {
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
-
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
           return operands_and_partials.value(0.0);
       }
 
-      // Compute CDF and its gradients
-      using stan::math::gamma_q;
-      using stan::math::digamma;
       using boost::math::tgamma;
       using std::exp;
       using std::pow;
 
-      // Cache a few expensive function calls if nu is a parameter
       VectorBuilder<!is_constant_struct<T_dof>::value,
                     T_partials_return, T_dof> gamma_vec(stan::length(nu));
       VectorBuilder<!is_constant_struct<T_dof>::value,
@@ -112,7 +97,6 @@ namespace stan {
         }
       }
 
-      // Compute vectorized CDF and gradient
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
@@ -120,7 +104,6 @@ namespace stan {
           continue;
         }
 
-        // Pull out values
         const T_partials_return y_dbl = value_of(y_vec[n]);
         const T_partials_return y_inv_dbl = 1.0 / y_dbl;
         const T_partials_return half_nu_dbl = 0.5 * value_of(nu_vec[n]);
@@ -130,7 +113,6 @@ namespace stan {
         const T_partials_return half_nu_s2_overx_dbl
           = 2.0 * half_nu_dbl * half_s2_overx_dbl;
 
-        // Compute
         const T_partials_return Pn = gamma_q(half_nu_dbl, half_nu_s2_overx_dbl);
         const T_partials_return gamma_p_deriv = exp(-half_nu_s2_overx_dbl)
           * pow(half_nu_s2_overx_dbl, half_nu_dbl-1) / tgamma(half_nu_dbl);
@@ -141,14 +123,12 @@ namespace stan {
           operands_and_partials.d_x1[n] += half_nu_s2_overx_dbl * y_inv_dbl
             * gamma_p_deriv / Pn;
 
-
-
         if (!is_constant_struct<T_dof>::value)
           operands_and_partials.d_x2[n]
-            += (0.5 * stan::math::grad_reg_inc_gamma(half_nu_dbl,
-                                                     half_nu_s2_overx_dbl,
-                                                     gamma_vec[n],
-                                                     digamma_vec[n])
+            += (0.5 * grad_reg_inc_gamma(half_nu_dbl,
+                                         half_nu_s2_overx_dbl,
+                                         gamma_vec[n],
+                                         digamma_vec[n])
                 - half_s2_overx_dbl * gamma_p_deriv)
             / Pn;
 
@@ -170,9 +150,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(s); ++n)
           operands_and_partials.d_x3[n] *= P;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
