@@ -19,28 +19,19 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_loc, typename T_scale, typename T_shape>
     typename return_type<T_y, T_loc, T_scale, T_shape>::type
     skew_normal_ccdf_log(const T_y& y, const T_loc& mu, const T_scale& sigma,
                          const T_shape& alpha) {
-      static const char* function("stan::math::skew_normal_ccdf_log");
+      static const char* function("skew_normal_ccdf_log");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale,
                                                   T_shape>::type
         T_partials_return;
 
-      using stan::math::check_positive;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::owens_t;
-      using stan::math::value_of;
-
       T_partials_return ccdf_log(0.0);
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)
@@ -62,8 +53,6 @@ namespace stan {
       OperandsAndPartials<T_y, T_loc, T_scale, T_shape>
         operands_and_partials(y, mu, sigma, alpha);
 
-      using stan::math::SQRT_2;
-      using stan::math::pi;
       using std::log;
       using std::exp;
 
@@ -72,7 +61,7 @@ namespace stan {
       VectorView<const T_scale> sigma_vec(sigma);
       VectorView<const T_shape> alpha_vec(alpha);
       size_t N = max_size(y, mu, sigma, alpha);
-      const double SQRT_TWO_OVER_PI = std::sqrt(2.0 / stan::math::pi());
+      const double SQRT_TWO_OVER_PI = std::sqrt(2.0 / pi());
 
       for (size_t n = 0; n < N; n++) {
         const T_partials_return y_dbl = value_of(y_vec[n]);
@@ -87,10 +76,8 @@ namespace stan {
         const T_partials_return ccdf_log_ = 1.0 - 0.5 * erfc(-scaled_diff)
           + 2 * owens_t(diff, alpha_dbl);
 
-        // ccdf_log
         ccdf_log += log(ccdf_log_);
 
-        // gradients
         const T_partials_return deriv_erfc = SQRT_TWO_OVER_PI * 0.5
           * exp(-scaled_diff_sq) / sigma_dbl;
         const T_partials_return deriv_owens = erf(alpha_dbl * scaled_diff)
@@ -109,9 +96,9 @@ namespace stan {
                                                       * (1.0 + alpha_dbl_sq))
             / ((1 + alpha_dbl_sq) * 2.0 * pi()) / ccdf_log_;
       }
-
       return operands_and_partials.value(ccdf_log);
     }
+
   }
 }
 #endif
