@@ -21,7 +21,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_shape, typename T_scale>
@@ -30,15 +29,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_shape, T_scale>::type
         T_partials_return;
 
-      static const char* function("stan::math::weibull_ccdf_log");
+      static const char* function("weibull_ccdf_log");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_nonnegative;
       using boost::math::tools::promote_args;
-      using stan::math::value_of;
       using std::log;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(alpha)
             && stan::length(sigma)))
@@ -62,10 +57,8 @@ namespace stan {
         const T_partials_return alpha_dbl = value_of(alpha_vec[n]);
         const T_partials_return pow_ = pow(y_dbl / sigma_dbl, alpha_dbl);
 
-        // ccdf_log
         ccdf_log -= pow_;
 
-        // gradients
         if (!is_constant_struct<T_y>::value)
           operands_and_partials.d_x1[n] -= alpha_dbl / y_dbl * pow_;
         if (!is_constant_struct<T_shape>::value)
@@ -73,9 +66,9 @@ namespace stan {
         if (!is_constant_struct<T_scale>::value)
           operands_and_partials.d_x3[n] += alpha_dbl / sigma_dbl * pow_;
       }
-
       return operands_and_partials.value(ccdf_log);
     }
+
   }
 }
 #endif
