@@ -2,17 +2,16 @@
 #define STAN_MATH_REV_CORE_CHAINABLE_ALLOC_HPP
 
 #include <stan/math/rev/core/chainablestack.hpp>
-#include <stdexcept>
 
 namespace stan {
   namespace math {
 
-
     /**
-     * A chainable_alloc is an object which is constructed and destructed normally
-     * but the memory lifespan is managed along with the arena allocator for the
-     * gradient calculation.  A chainable_alloc should never be created on the
-     * stack, only with a new call.
+     * A chainable_alloc is an object which is constructed and
+     * destructed normally but the memory lifespan is managed along
+     * with the arena allocator for the gradient calculation.  A
+     * chainable_alloc instance must be created with a call to
+     * operator new for memory management.
      */
     class chainable_alloc {
     public:
