@@ -13,7 +13,7 @@ namespace stan {
       const size_t size_;
       vari** vis_;
     public:
-      op_vector_vari(double f, const std::vector<stan::math::var>& vs) :
+      op_vector_vari(double f, const std::vector<var>& vs) :
         vari(f),
         size_(vs.size()) {
         vis_ = reinterpret_cast<vari**>
