@@ -38,8 +38,6 @@
 #include <stan/math/rev/mat/fun/rows_dot_product.hpp>
 #include <stan/math/rev/mat/fun/sd.hpp>
 #include <stan/math/rev/mat/fun/softmax.hpp>
-#include <stan/math/rev/mat/fun/sort_asc.hpp>
-#include <stan/math/rev/mat/fun/sort_desc.hpp>
 #include <stan/math/rev/mat/fun/squared_distance.hpp>
 #include <stan/math/rev/mat/fun/stan_print.hpp>
 #include <stan/math/rev/mat/fun/sum.hpp>
