@@ -11,7 +11,7 @@ namespace stan {
       class log1m_vari : public op_v_vari {
       public:
         explicit log1m_vari(vari* avi) :
-          op_v_vari(stan::math::log1p(-avi->val_), avi) {
+          op_v_vari(log1p(-avi->val_), avi) {
         }
         void chain() {
           avi_->adj_ += adj_ / (avi_->val_ - 1);
@@ -29,7 +29,7 @@ namespace stan {
      * @param a The variable.
      * @return The variable representing log of 1 minus the variable.
      */
-    inline var log1m(const stan::math::var& a) {
+    inline var log1m(const var& a) {
       return var(new log1m_vari(a.vi_));
     }
 
