@@ -3,7 +3,7 @@
 
 #include <math.h>
 #include <stan/math/rev/core.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
+#include <stan/math/prim/scal/fun/is_nan.hpp>
 #include <limits>
 
 #ifdef _MSC_VER
@@ -21,7 +21,7 @@ namespace stan {
           op_v_vari(::trunc(avi->val_), avi) {
         }
         void chain() {
-          if (unlikely(boost::math::isnan(avi_->val_)))
+          if (unlikely(is_nan(avi_->val_)))
             avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
         }
       };
